==> jboss-as-console-2.8.15.Final-sources.jar: org/jboss/as/console/client/shared/subsys/jca/AdminObjectList.java <==
package org.jboss.as.console.client.shared.subsys.jca;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.cellview.client.TextColumn;
import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.view.client.ListDataProvider;
import com.google.gwt.view.client.SelectionChangeEvent;
import com.google.gwt.view.client.SingleSelectionModel;
import org.jboss.as.console.client.Console;
import org.jboss.as.console.client.layout.MultipleToOneLayout;
import org.jboss.as.console.client.v3.dmr.AddressTemplate;
import org.jboss.as.console.client.v3.dmr.ResourceDescription;
import org.jboss.as.console.client.v3.widgets.AddPropertyDialog;
import org.jboss.as.console.client.v3.widgets.PropertyEditor;
import org.jboss.as.console.client.v3.widgets.SubResourceAddPropertyDialog;
import org.jboss.as.console.client.v3.widgets.SubResourcePropertyManager;
import org.jboss.as.console.mbui.widgets.ModelNodeFormBuilder;
import org.jboss.ballroom.client.rbac.SecurityContext;
import org.jboss.ballroom.client.widgets.forms.FormCallback;
import org.jboss.ballroom.client.widgets.tables.DefaultCellTable;
import org.jboss.ballroom.client.widgets.tools.ToolButton;
import org.jboss.ballroom.client.widgets.tools.ToolStrip;
import org.jboss.ballroom.client.widgets.window.Feedback;
import org.jboss.dmr.client.Property;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * @author Heiko Braun
 */
public class AdminObjectList {


    private final ResourceAdapterPresenter presenter;
    private final static AddressTemplate ADDRESS_TEMPLATE = AddressTemplate.of("{selected.profile}/subsystem=resource-adapters/resource-adapter=*/admin-objects=*");
    private final static AddressTemplate PROPS_ADDRESS = ADDRESS_TEMPLATE.append("config-properties=*");

    private final DefaultCellTable table;
    private final ListDataProvider<Property> dataProvider;
    private SingleSelectionModel<Property> selectionModel;
    private SubResourceAddPropertyDialog addDialog;
    private PropertyEditor configProperties;

    public AdminObjectList(ResourceAdapterPresenter presenter) {
        this.presenter = presenter;

        this.table = new DefaultCellTable(5);
        this.dataProvider = new ListDataProvider<Property>();
        this.dataProvider.addDataDisplay(table);
    }

    public Widget asWidget() {
        TextColumn<Property> nameColumn = new TextColumn<Property>() {
            @Override
            public String getValue(Property node) {
                return node.getName();
            }
        };

        table.addColumn(nameColumn, "Name");

        ToolStrip tools = new ToolStrip();
        tools.addToolButtonRight(new ToolButton(Console.CONSTANTS.common_label_add(), new ClickHandler() {
            @Override
            public void onClick(ClickEvent event) {
                presenter.onLaunchAddWizard(ADDRESS_TEMPLATE);
            }
        }));
        tools.addToolButtonRight(new ToolButton(Console.CONSTANTS.common_label_delete(), new ClickHandler() {
            @Override
            public void onClick(ClickEvent event) {
                Feedback.confirm(Console.MESSAGES.deleteTitle("Admin Object"),
                        Console.MESSAGES.deleteConfirm(" Admin Object '" + getCurrentSelection().getName() + "'"),
                        new Feedback.ConfirmationHandler() {
                            @Override
                            public void onConfirmation(boolean isConfirmed) {
                                if (isConfirmed) {
                                    presenter.onRemoveChildResource(ADDRESS_TEMPLATE, getCurrentSelection());
                                }
                            }
                        });
            }
        }));

        SecurityContext securityContext = presenter.getSecurityFramework().getSecurityContext(presenter.getProxy().getNameToken());
        ResourceDescription definition = presenter.getDescriptionRegistry().lookup(ADDRESS_TEMPLATE);

        ModelNodeFormBuilder builder = new ModelNodeFormBuilder()
                .setConfigOnly()
                .setResourceDescription(definition)
                .setSecurityContext(securityContext);

        final ModelNodeFormBuilder.FormAssets formAssets = builder.build();

        formAssets.getForm().setToolsCallback(new FormCallback() {
            @Override
            public void onSave(Map changeset) {
                presenter.onSaveChildResource(ADDRESS_TEMPLATE, getCurrentSelection().getName(), changeset);
            }

            @Override
            public void onCancel(Object entity) {
                formAssets.getForm().cancel();
            }
        });

        SubResourcePropertyManager propertyManager = new SubResourcePropertyManager(PROPS_ADDRESS, presenter.getStatementContext(), presenter.getDispatcher())
        {
            @Override
            public void onAdd(Property property, AddPropertyDialog addDialog) {
                presenter.onCreateProperty(PROPS_ADDRESS, property.getValue(), getCurrentSelection().getName(), property.getName());
                AdminObjectList.this.addDialog.hide();
            }

            @Override
            public void onRemove(Property property) {
                presenter.onRemoveProperty(PROPS_ADDRESS, getCurrentSelection().getName(), property.getName());
                AdminObjectList.this.addDialog.hide();
            }
        };

        addDialog =
                new SubResourceAddPropertyDialog(
                        propertyManager,
                        securityContext,
                        definition.getChildDescription("config-properties")
                );

        configProperties = new PropertyEditor.Builder(propertyManager)
                .addDialog(addDialog)
                .operationAddress(PROPS_ADDRESS) // this address is used in the security context
                .build();


        // ----
        final MultipleToOneLayout layoutBuilder = new MultipleToOneLayout()
                .setPlain(true)
                .setHeadline("Admin Objects")
                .setDescription(definition.get("description").asString())
                .setMasterTools(tools)
                .setMaster("", table)
                .addDetail("Attributes", formAssets.asWidget())
                .addDetail("Configuration Properties", configProperties.asWidget()
                );

        selectionModel = new SingleSelectionModel<Property>();
        selectionModel.addSelectionChangeHandler(new SelectionChangeEvent.Handler() {
            @Override
            public void onSelectionChange(SelectionChangeEvent event) {
                Property adminObject = selectionModel.getSelectedObject();
                if(adminObject!=null)
                {
                    formAssets.getForm().edit(adminObject.getValue());

                    List<Property> props = adminObject.getValue().hasDefined("config-properties") ?
                                    adminObject.getValue().get("config-properties").asPropertyList() : Collections.EMPTY_LIST;

                    configProperties.update(props);
                }
                else
                {
                    formAssets.getForm().clearValues();
                }
            }
        });
        table.setSelectionModel(selectionModel);
        return layoutBuilder.build();
    }

    private Property getCurrentSelection() {
        return ((SingleSelectionModel<Property>)table.getSelectionModel()).getSelectedObject();
    }

    public void setData(List<Property> data) {
        selectionModel.clear();
        dataProvider.setList(data);
        table.selectDefaultEntity();

    }
}

==> jboss-as-console-2.9.12.Final-sources.jar: org/jboss/as/console/client/shared/subsys/jca/AdminObjectList.java <==
package org.jboss.as.console.client.shared.subsys.jca;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.cellview.client.TextColumn;
import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.view.client.ListDataProvider;
import com.google.gwt.view.client.SelectionChangeEvent;
import com.google.gwt.view.client.SingleSelectionModel;
import org.jboss.as.console.client.Console;
import org.jboss.as.console.client.layout.MultipleToOneLayout;
import org.jboss.as.console.client.v3.dmr.AddressTemplate;
import org.jboss.as.console.client.v3.dmr.ResourceDescription;
import org.jboss.as.console.client.v3.widgets.AddPropertyDialog;
import org.jboss.as.console.client.v3.widgets.PropertyEditor;
import org.jboss.as.console.client.v3.widgets.SubResourceAddPropertyDialog;
import org.jboss.as.console.client.v3.widgets.SubResourcePropertyManager;
import org.jboss.as.console.mbui.widgets.ModelNodeFormBuilder;
import org.jboss.ballroom.client.rbac.SecurityContext;
import org.jboss.ballroom.client.widgets.forms.FormCallback;
import org.jboss.ballroom.client.widgets.tables.DefaultCellTable;
import org.jboss.ballroom.client.widgets.tools.ToolButton;
import org.jboss.ballroom.client.widgets.tools.ToolStrip;
import org.jboss.ballroom.client.widgets.window.Feedback;
import org.jboss.dmr.client.Property;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * @author Heiko Braun
 */
public class AdminObjectList {


    private final ResourceAdapterPresenter presenter;
    private final static AddressTemplate ADDRESS_TEMPLATE = AddressTemplate.of("{selected.profile}/subsystem=resource-adapters/resource-adapter=*/admin-objects=*");
    private final static AddressTemplate PROPS_ADDRESS = ADDRESS_TEMPLATE.append("config-properties=*");

    private final DefaultCellTable table;
    private final ListDataProvider<Property> dataProvider;
    private SingleSelectionModel<Property> selectionModel;
    private SubResourceAddPropertyDialog addDialog;
    private PropertyEditor configProperties;

    public AdminObjectList(ResourceAdapterPresenter presenter) {
        this.presenter = presenter;

        this.table = new DefaultCellTable(5);
        this.dataProvider = new ListDataProvider<Property>();
        this.dataProvider.addDataDisplay(table);
    }

    public Widget asWidget() {
        TextColumn<Property> nameColumn = new TextColumn<Property>() {
            @Override
            public String getValue(Property node) {
                return node.getName();
            }
        };

        table.addColumn(nameColumn, "Name");

        ToolStrip tools = new ToolStrip();
        tools.addToolButtonRight(new ToolButton(Console.CONSTANTS.common_label_add(), new ClickHandler() {
            @Override
            public void onClick(ClickEvent event) {
                presenter.onLaunchAddWizard(ADDRESS_TEMPLATE);
            }
        }));
        tools.addToolButtonRight(new ToolButton(Console.CONSTANTS.common_label_delete(), new ClickHandler() {
            @Override
            public void onClick(ClickEvent event) {
                Feedback.confirm(Console.MESSAGES.deleteTitle("Admin Object"),
                        Console.MESSAGES.deleteConfirm(" Admin Object '" + getCurrentSelection().getName() + "'"),
                        new Feedback.ConfirmationHandler() {
                            @Override
                            public void onConfirmation(boolean isConfirmed) {
                                if (isConfirmed) {
                                    presenter.onRemoveChildResource(ADDRESS_TEMPLATE, getCurrentSelection());
                                }
                            }
                        });
            }
        }));

        SecurityContext securityContext = presenter.getSecurityFramework().getSecurityContext(presenter.getProxy().getNameToken());
        ResourceDescription definition = presenter.getDescriptionRegistry().lookup(ADDRESS_TEMPLATE);

        ModelNodeFormBuilder builder = new ModelNodeFormBuilder()
                .setConfigOnly()
                .setResourceDescription(definition)
                .setSecurityContext(securityContext);

        final ModelNodeFormBuilder.FormAssets formAssets = builder.build();

        formAssets.getForm().setToolsCallback(new FormCallback() {
            @Override
            public void onSave(Map changeset) {
                presenter.onSaveChildResource(ADDRESS_TEMPLATE, getCurrentSelection().getName(), changeset);
            }

            @Override
            public void onCancel(Object entity) {
                formAssets.getForm().cancel();
            }
        });

        SubResourcePropertyManager propertyManager = new SubResourcePropertyManager(PROPS_ADDRESS, presenter.getStatementContext(), presenter.getDispatcher())
        {
            @Override
            public void onAdd(Property property, AddPropertyDialog addDialog) {
                presenter.onCreateProperty(PROPS_ADDRESS, property.getValue(), getCurrentSelection().getName(), property.getName());
                AdminObjectList.this.addDialog.hide();
            }

            @Override
            public void onRemove(Property property) {
                presenter.onRemoveProperty(PROPS_ADDRESS, getCurrentSelection().getName(), property.getName());
                AdminObjectList.this.addDialog.hide();
            }
        };

        addDialog =
                new SubResourceAddPropertyDialog(
                        propertyManager,
                        securityContext,
                        definition.getChildDescription("config-properties")
                );

        configProperties = new PropertyEditor.Builder(propertyManager)
                .addDialog(addDialog)
                .operationAddress(PROPS_ADDRESS) // this address is used in the security context
                .build();


        // ----
        final MultipleToOneLayout layoutBuilder = new MultipleToOneLayout()
                .setPlain(true)
                .setHeadline("Admin Objects")
                .setDescription(definition.get("description").asString())
                .setMasterTools(tools)
                .setMaster("", table)
                .addDetail(Console.CONSTANTS.common_label_attributes(), formAssets.asWidget())
                .addDetail(Console.CONSTANTS.common_label_properties(), configProperties.asWidget());

        selectionModel = new SingleSelectionModel<Property>();
        selectionModel.addSelectionChangeHandler(new SelectionChangeEvent.Handler() {
            @Override
            public void onSelectionChange(SelectionChangeEvent event) {
                Property adminObject = selectionModel.getSelectedObject();
                if(adminObject!=null)
                {
                    formAssets.getForm().edit(adminObject.getValue());

                    List<Property> props = adminObject.getValue().hasDefined("config-properties") ?
                                    adminObject.getValue().get("config-properties").asPropertyList() : Collections.EMPTY_LIST;

                    configProperties.update(props);
                }
                else
                {
                    formAssets.getForm().clearValues();
                }
            }
        });
        table.setSelectionModel(selectionModel);
        return layoutBuilder.build();
    }

    private Property getCurrentSelection() {
        return ((SingleSelectionModel<Property>)table.getSelectionModel()).getSelectedObject();
    }

    public void setData(List<Property> data) {
        selectionModel.clear();
        dataProvider.setList(data);
        table.selectDefaultEntity();

    }
}
